@@ -1,10 +1,5 @@
 # -*- coding: utf-8 -*-
 import os
-import re
-import sys
-import time
-import datetime
-import gzip
 import glob
 from mimetypes import MimeTypes
 
@@ -32,9 +27,9 @@ def set_dirs(source):
     source = source
     photo_target = os.path.join(conf.PROJECT_DIR, 'media', 'uploads', 'photos')
     video_target = os.path.join(conf.PROJECT_DIR, 'media', 'uploads', 'videos')
-    if os.path.exists(photo_target) == False:
+    if os.path.exists(photo_target) is False:
         mkdir_p(photo_target)
-    if os.path.exists(video_target) == False:
+    if os.path.exists(video_target) is False:
         mkdir_p(video_target)
     return source, photo_target, video_target
 
