@@ -1,25 +1,21 @@
 # -*- coding: utf-8 -*-
 
-import os, errno
+import os
+import errno
 import re
-import sys
-import time
-import datetime
-import gzip
-import glob
 from datetime import datetime
-from pprint import pprint
 from subprocess import Popen, PIPE
 
-from django.core.management.base import BaseCommand, CommandError
 from django.template.defaultfilters import slugify
 from django.template import Context, Template
 from django.conf import settings as conf
 
-import Image, ExifTags
+import Image
+import ExifTags
 from ExifTags import TAGS
 from sorl.thumbnail import get_thumbnail
 from shutil import copyfile
+from taggit.models import Tag
 
 from rgallery.engine import expire_view_cache
 
@@ -31,20 +27,23 @@ import rgallery.models as mymodels
 def mkdir_p(path):
     try:
         os.makedirs(path)
-    except OSError as exc: # Python >2.5
+    except OSError as exc:  # Python >2.5
         if exc.errno == errno.EEXIST and os.path.isdir(path):
             pass
-        else: raise
+        else:
+            raise
 
 
 def namedup(nombre, photodestdir):
-    nombre_imagen = "%s%s" % (slugify(str(os.path.splitext(nombre)[0]).replace('/', '').replace(' ','_').replace(':','-')),
-                            str(os.path.splitext(nombre)[1]))
+    nombre_imagen = "%s%s" % (slugify(
+        str(os.path.splitext(nombre)[0]).replace('/', '').replace(' ','_').replace(':','-')),
+        str(os.path.splitext(nombre)[1]))
 
     # Descargar original a img (si ya existe _1.jpg)
     if os.path.exists(os.path.join(photodestdir, nombre_imagen)) == True:
-        nombre_imagen = "%s_1%s" % (slugify(str(os.path.splitext(nombre)[0]).replace('/', '').replace(' ','_').replace(':','-')),
-                                         str(os.path.splitext(nombre)[1]))
+        nombre_imagen = "%s_1%s" % (slugify(
+            str(os.path.splitext(nombre)[0]).replace('/', '').replace(' ','_').replace(':','-')),
+            str(os.path.splitext(nombre)[1]))
         print "      Duped in disk, name changed to: %s" % nombre_imagen
     return nombre_imagen
 
@@ -82,15 +81,15 @@ def img_rotate(im2):
     try:
         # Rotar si es necesario
         for orientation in ExifTags.TAGS.keys():
-            if ExifTags.TAGS[orientation]=='Orientation':
+            if ExifTags.TAGS[orientation] == 'Orientation':
                 break
-        exif=dict(im2._getexif().items())
+        exif = dict(im2._getexif().items())
         if exif[orientation] == 3:
-            im2=im2.rotate(180, expand=True)
+            im2 = im2.rotate(180, expand=True)
         elif exif[orientation] == 6:
-            im2=im2.rotate(270, expand=True)
+            im2 = im2.rotate(270, expand=True)
         elif exif[orientation] == 8:
-            im2=im2.rotate(90, expand=True)
+            im2 = im2.rotate(90, expand=True)
     except:
         pass
 
@@ -123,15 +122,18 @@ def video_convert(video, file, srcdir, destdir, video_name, rotate):
     # Convertir con FFMPEG      (en principio no hace falta convertir...)
     # Hacer thumb               (...pero hace falta hacer thumb)
 
-    # ffmpeg -i [sourcefile.avi] -acodec mp3 -ar 22050 -ab 32 -f flv -s 320×240 [destfile.flv]
+    # ffmpeg -i [sourcefile.avi] -acodec mp3 -ar 22050 -ab 32 -f flv -s \
+    # 320×240 [destfile.flv]
     # flvtool2 -U [flvfile]
-    # ffmpeg -y -i [videofile] -vframes 1 -ss 00:00:02 -an -vcodec png -f rawvideo -s 320×240 [thumbnailimage.png]
+    # ffmpeg -y -i [videofile] -vframes 1 -ss 00:00:02 -an -vcodec png -f \
+    # rawvideo -s 320×240 [thumbnailimage.png]
     #
-    # convertvideo = "%s -i %s -acodec %s -ar 22050 -ab 32 -f flv -s %s %s" % (conf.ZERO14_FFMPEG, src,
-    #                                                 conf.ZERO14_FFMPEG_ACODEC, conf.ZERO14_FFMPEG_VIDEO_SIZE,
-    #                                                 flvfile)
+    # convertvideo = "%s -i %s -acodec %s -ar 22050 -ab 32 -f flv -s %s %s" % \
+    #    (conf.ZERO14_FFMPEG, src, conf.ZERO14_FFMPEG_ACODEC, \
+    #    conf.ZERO14_FFMPEG_VIDEO_SIZE, flvfile)
     # MarcosBL:
-    # ffmpeg -vstats_file /tmp/vstats -i "$1" -f mp4 -vcodec libx264 -r 25 -b 560000 -ab 64 -ar 44100 -threads 0 "$2" 2>/dev/null &
+    # ffmpeg -vstats_file /tmp/vstats -i "$1" -f mp4 -vcodec libx264 -r 25 -b \
+    # 560000 -ab 64 -ar 44100 -threads 0 "$2" 2>/dev/null &
 
     try:
         src = file.path
@@ -156,11 +158,12 @@ def video_convert(video, file, srcdir, destdir, video_name, rotate):
     # FFMPEG_THUMB_SIZE='444x250'
     # FFMPEG_THUMB_SIZE_INVERSE='250x444'
 
-    grabimage = "%s -y -i '%s' -vframes 1 -ss 00:00:00 -an -vcodec %s -f rawvideo -s %s %s %s " % (conf.FFMPEG, src,
-                                                                                              conf.FFMPEG_VCODEC_THUMB,
-                                                                                              size,
-                                                                                              transpose,
-                                                                                              thumb)
+    grabimage = "%s -y -i '%s' -vframes 1 -ss 00:00:00 -an -vcodec %s -f rawvideo -s %s %s %s " % (
+        conf.FFMPEG, src,
+        conf.FFMPEG_VCODEC_THUMB,
+        size,
+        transpose,
+        thumb)
     #os.system(convertvideo)
     #print "      [%s]" % grabimage
     os.system(grabimage)
@@ -178,7 +181,8 @@ def video_convert(video, file, srcdir, destdir, video_name, rotate):
 
 # MEDIASYNC ********************************************************************
 
-def mediasync(file, srcdir, photodestdir, videodestdir, thumbs, backend, client, img_duped, vid_duped, img_total, vid_total, total):
+def mediasync(file, srcdir, photodestdir, videodestdir, thumbs, backend,
+              client, img_duped, vid_duped, img_total, vid_total, total, tags):
 
     filename = os.path.basename(backend.filepath(file))
     if backend.is_image(file):
@@ -189,14 +193,18 @@ def mediasync(file, srcdir, photodestdir, videodestdir, thumbs, backend, client,
         except:
             # Downloading
             print "%04d - Image %s not in database, downlaoding, thumbing and adding to database" % (total, filename)
-            nombre_imagen = namedup(filename, photodestdir) # If duped adds '_1' to the name
-            img = backend.download(client, file, nombre_imagen, srcdir, photodestdir)
+            # If duped adds '_1' to the name
+            nombre_imagen = namedup(filename, photodestdir)
+            img = backend.download(client, file, nombre_imagen,
+                                   srcdir, photodestdir)
             print "      Saved: %s/%s" % (photodestdir, nombre_imagen)
 
             # Reading EXIF Data
             data_image = img_get_exif(img)
             try:
-                capture_data = datetime.strptime(str(data_image['DateTimeOriginal']), "%Y:%m:%d %H:%M:%S")
+                capture_data = datetime.strptime(
+                    str(data_image['DateTimeOriginal']),
+                    "%Y:%m:%d %H:%M:%S")
             except:
                 capture_data = datetime.now()
 
@@ -207,12 +215,20 @@ def mediasync(file, srcdir, photodestdir, videodestdir, thumbs, backend, client,
                                 capture_date=capture_data,
                                 status=True)
             im.save()
+            if len(tags) > 0:
+                for tag in tags:
+                    try:
+                        t = Tag.objects.get(slug=tag)
+                        im.tags.add(t)
+                    except:
+                        im.tags.add(tag)
+            im.save()
             img_total += 1
             print "      Added to database (%s)" % im.origen
 
             # Open image to modify
-            im2 = Image.open(img) # Open
-            im2 = img_rotate(im2) # Rotate
+            im2 = Image.open(img)  # Open
+            im2 = img_rotate(im2)  # Rotate
             im2.save(os.path.join(photodestdir, nombre_imagen))
 
             # Creating thumbs
@@ -231,16 +247,20 @@ def mediasync(file, srcdir, photodestdir, videodestdir, thumbs, backend, client,
         except:
             # Downloading
             print "%04d - Video %s not in database, downloading, thumbing and adding to database" % (total, filename)
-            video_name = namedup(filename, videodestdir) # If duped adds '_1' to the name
-            video = backend.download(client, file, video_name, srcdir, videodestdir)
+            # If duped adds '_1' to the name
+            video_name = namedup(filename, videodestdir)
+            video = backend.download(
+                client, file, video_name, srcdir, videodestdir)
             print "      Saved: %s/%s" % (videodestdir, video_name)
 
             # Reading EXIF Data
             rotate, data_video = video_get_exif(video)
-            capture_data = datetime.strptime(str(data_video), "%Y-%m-%d %H:%M:%S")
+            capture_data = datetime.strptime(
+                str(data_video), "%Y-%m-%d %H:%M:%S")
 
             # Converting + thumb
-            thumbname = video_convert(video, file, srcdir, videodestdir, video_name, rotate)
+            thumbname = video_convert(
+                video, file, srcdir, videodestdir, video_name, rotate)
 
             # Adding to database
             vid = mymodels.Photo(title=capture_data,
